==> haskell-gtk-strut-0.1.3.2-207-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-Kfmt2UjiJrH8aMucW7B9pT
key:                  gtk-strut-0.1.3.2-Kfmt2UjiJrH8aMucW7B9pT
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  c91f635e53cce1a8a63b141460ef56cb
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-Kfmt2UjiJrH8aMucW7B9pT
depends:
    base-4.17.2.1 data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    gi-gdk-3.0.26-AjUZWDk9WBwBa5IC1II5Ci
    gi-gtk-3.0.39-BBPUeFrK3LOFAx59n0BMAL
    hslogger-1.3.1.2-7cqGvFW2jLnLcroti46V3f text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk-strut-0.1.3.2-217-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-5HvbOZ66NaU2Pnu36Rswws
key:                  gtk-strut-0.1.3.2-5HvbOZ66NaU2Pnu36Rswws
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  1863bb2b5c0b13619420c75dcee1cd5a
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-5HvbOZ66NaU2Pnu36Rswws
depends:
    base-4.17.2.1 data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    gi-gdk-3.0.26-KSx2IdGu5lCECxlgC8trR0
    gi-gtk-3.0.39-Bn8GdKXXJNQ1Agi2bwPoC0
    hslogger-1.3.1.2-9sF7cXQtpfuHv5JeUWstYz text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
